@@ -18,10 +18,10 @@
  *    You should have received a copy of the GNU General Public License
  *    along with GnuDOS.  If not, see <http://www.gnu.org/licenses/>.
  */    
-#include "dialogs.h"
-#include "screen.h"
-#include "kbd.h"
-#include "mouse.h"
+#include "console/dialogs.h"
+#include "console/screen.h"
+#include "console/kbd.h"
+//#include "console/mouse.h"
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -41,12 +41,12 @@ void sighandler(int signo)
 
 int main(int argc, char *argv[]) 
 {
- if(!init_kbd()) 
+ if(!initTerminal()) 
  {
    fprintf(stderr, "Error initializing keyboard. Aborting.\n");
    exit(1);
  }
- init_mouse();
+ //init_mouse();
  
  //clear the screen
  clearScreen();
@@ -64,8 +64,6 @@ int main(int argc, char *argv[])
  }
  //very important to restore keyboard state to its
  //previous state before exiting
- restore_kbd();
+ restoreTerminal();
  exit(0);
-}//end main
-
-      
+}//end main
\ No newline at end of file
