@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: kbd.h
  *    This file is part of the GnuDOS project.
@@ -31,22 +31,37 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+/* Define the boolean type */
+#ifndef __BOOL_DEFINED_
+#define __BOOL_DEFINED_
 typedef int bool;
+#endif
 
-bool ALT;
-bool CTRL;
-bool SHIFT;
-bool CAPS;
-bool INSERT;
+#ifdef KBD
+#   define KBD_EXTERN
+#else
+#   define KBD_EXTERN  extern
+#endif
 
+KBD_EXTERN unsigned short mask[];
+/* Control (Meta) Keys */
+KBD_EXTERN bool ALT;
+KBD_EXTERN bool CTRL;
+KBD_EXTERN bool SHIFT;
+KBD_EXTERN bool CAPS;
+KBD_EXTERN bool INSERT;
+
+/* Initialize the terminal for program use */
 int initTerminal();
+/* Restore the terminal before program exits */
 void restoreTerminal();
-//int init_kbd();
-//void restore_kbd();
 
+/* A flag indicating if we are running under X */
 bool X_IS_RUNNING;
+/* Pilot function to get next key press */
 int getKey();
 
+/* Control and Function key definitions */
 #define ESC_KEY		27
 #define BACKSPACE_KEY	8
 #define TAB_KEY		9
@@ -68,5 +83,19 @@ int getKey();
 #define SHIFT_UP	18
 #define PGUP_KEY	19
 #define PGDOWN_KEY	20
+#define F1_KEY		21
+#define F2_KEY		22
+#define F3_KEY		23
+#define F4_KEY		24
+#define F5_KEY		25
+#define F6_KEY		26
+#define F7_KEY		28
+#define F8_KEY		29
+#define F9_KEY		30
+#define F10_KEY		31
+#define F11_KEY		33
+#define F12_KEY		34
+#define NUM_KEY		35
+#define SCRL_KEY	36
 
-#endif
+#endif /* __KBD_H */
