@@ -193,7 +193,8 @@ void undoAddChar(undoActionType utype, int lwhere, int cwhere, char what)
     }
     if(cwhere == undo->charStart)
     {
-        for(int i = undoBufIndex; i > 0; i--)
+        int i;
+        for(i = undoBufIndex; i > 0; i--)
             undoBuf[undoBufIndex] = undoBuf[undoBufIndex-1];
         undoBuf[0] = what;
         //initUndoAction(undo, utype, lwhere, cwhere);
