@@ -214,7 +214,8 @@ int __initNewDocument()
 {
     if(totalLines)
     {
-        for(int i = 0; i < totalLines; i++) freeLineStruct(lines[i]);
+	int i;
+        for(i = 0; i < totalLines; i++) freeLineStruct(lines[i]);
         totalLines = 0;
     }
     lines[0] = allocLineStructB(maxLen);
