@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: cutcopy.h
  *    This file contains function prototypes and variable declarations
@@ -37,15 +37,26 @@ void removeCopyDir(int i);
 int checkCutOrCopyDir(int i);
 int checkCutOrCopyFile(int i);
 
-#define MAX_CUT_COPY	20
-char *cutFiles[20];
-char *cutDirs[20];
-char *copyFiles[20];
-char *copyDirs[20];
+#ifdef CUTCOPY
+#   define CUTCOPY_EXTERN
+#else
+#   define CUTCOPY_EXTERN   extern
+#endif
 
-int numCutFiles;
-int numCopyFiles;
-int numCutDirs;
-int numCopyDirs;
+CUTCOPY_EXTERN int numCutFiles;
+CUTCOPY_EXTERN int numCopyFiles;
+CUTCOPY_EXTERN int numCutDirs;
+CUTCOPY_EXTERN int numCopyDirs;
 
-#endif
\ No newline at end of file
+//variables used in editing of dirs and files//
+CUTCOPY_EXTERN int numStarred;		//number of items starred (marked)
+CUTCOPY_EXTERN int numCut;		//number of items set to be cut
+CUTCOPY_EXTERN int numCopy;		//number of items selected for copy
+
+#define MAX_CUT_COPY	256
+CUTCOPY_EXTERN char *cutFiles [MAX_CUT_COPY];
+CUTCOPY_EXTERN char *cutDirs  [MAX_CUT_COPY];
+CUTCOPY_EXTERN char *copyFiles[MAX_CUT_COPY];
+CUTCOPY_EXTERN char *copyDirs [MAX_CUT_COPY];
+
+#endif
