@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: find.h
  *    This file contains function prototypes and variable declarations
@@ -28,25 +28,30 @@
 #include <dirent.h>
 #include <sys/stat.h>
 
-int input1_len;//length of the searched file name
-int input2_len;//length of the path to search in
 #define MAX_INPUT1_LEN  43//max length of the searched file name
 #define MAX_INPUT2_LEN  23//max length of the path to search in
-int highlight1;	//highlighted char in input field 1
-int highlight2;	//highlighted char in input field 2
-char findFileName[MAX_INPUT1_LEN];	//filename to be searched for
-char findInDir[MAX_INPUT2_LEN];	//optional for user--path to search in
 
-struct stat statbuf;
+#ifdef FIND
+#   define FIND_EXTERN
+#else
+#   define FIND_EXTERN  extern
+#endif
+
+FIND_EXTERN int input1_len;//length of the searched file name
+FIND_EXTERN int input2_len;//length of the path to search in
+FIND_EXTERN int highlight1;	//highlighted char in input field 1
+FIND_EXTERN int highlight2;	//highlighted char in input field 2
+FIND_EXTERN char findFileName[MAX_INPUT1_LEN];	//filename to be searched for
+FIND_EXTERN char findInDir[MAX_INPUT2_LEN];	//optional for user--path to search in
+FIND_EXTERN char *startStr;
+FIND_EXTERN char *middleStr;
+FIND_EXTERN char *endStr;
 
 void findFile();
 //function called by findFile() function
-void scanDirForFile(char tmp[], int level);
+void scanDirForFile(char *tmp, int level);
 void showSearchResults();
 
-char *startStr;
-char *middleStr;
-char *endStr;
 int compareFileName(char *name);
 
-#endif
\ No newline at end of file
+#endif
