@@ -101,7 +101,8 @@ void drawMenuBox(struct menustruct *curMenu)
     setScreenColorsI(COLOR_HIGHLIGHT_TEXT);
     fprintf(stdout, "\e[%d;%dH%s", x1, y1, menuItems[0]);
     setScreenColorsI(COLOR_WINDOW);
-    for(int i = 1; i < menuItemCount; i++) 
+    int i;
+    for(i = 1; i < menuItemCount; i++) 
     {
       fprintf(stdout, "\e[%d;%dH%s", i+4, y1, menuItems[i]);
     }
